# -*- coding: utf-8 -*-
# This is a test file intended to be used with pytest
# pytest automatically runs all the function starting with "test_"
# see https://docs.pytest.org for more information
import json
import os
from typing import Dict, List
import openai


def setup_openai():
    OPENAI_API_KEY = os.getenv("OPENAI_API_KEY", "")
    if OPENAI_API_KEY == "":
        raise ValueError("No \"OPENAI_API_KEY\" value set. Please set this env variable")
    openai.api_key = OPENAI_API_KEY


def _get_param_by_name(name: str) -> Dict:
    with open("./parameter-sets/api-configuration/parameter-set.json") as raw_file:
        raw_json = json.load(raw_file)
    params_list = raw_json.get("params", [])
    assert len(params_list) > 0

    params_engines = next(
        (param for param in params_list if param.get("name") == name),
        None
    )
    if params_engines is None:
        raise ValueError(f"No parameter with name {name}")
    return params_engines


def _get_engines_choices() -> List[str]:
    engines_param = _get_param_by_name("engine")
    return [choice.get("value", "") for choice in engines_param.get("selectChoices", {})]


def _get_openai_engines():
    models_raw = openai.Model.list().get("data", [])
    return [model.get("id") for model in models_raw]


def test_available_engines():
    setup_openai()
    open_ai_models = _get_openai_engines()
    # print(open_ai_models)
    engines = _get_engines_choices()
    assert "" not in engines
    assert len(engines) > 0

    for engine in engines:
        assert engine in open_ai_models
